==> wordpress_0.6.99.tar.gz: wordpress-0.6.99/src/themedatastorage.cpp <==
/*
 * themedatastorage.cpp
 *
 *  Created on: 27.5.2010
 *      Author: jlep
 */

#include <QFont>
#include <QPixmap>
#include <QLinearGradient>

#include "wpcommongeometry.h"
#include "themedatastorage.h"

#ifdef Q_OS_SYMBIAN
//const char* KButtonStyleSheet = "background-color: #ECECEC; font-size: 6pt; margin: 5px 0 3px 0; color: #333333;";
const char* KLabelStyleSheet = "background-color: #ECECEC; font-size: 6pt; margin: 5px 0px 3px 0px; color: #333333;";
#else
//const char* KButtonStyleSheet = "background-color: #ECECEC; font-size: 16pt; margin: 5px 0 3px 0; color: #333333;";
const char* KLabelStyleSheet = "background-color: #ECECEC; font-size: 16pt; margin: 5px 0px 3px 0px; color: #333333;";
#endif

ThemeData::ThemeData()
    : iStatusBarFont(NULL),
      iTabGradientBrush(NULL),
      iTabFont(NULL),
      iListItemPixmap(NULL),
      iOptionsPixmap(NULL),
      iMenuPixmap(NULL),
      iListTitleFont(NULL),
      iListContentFont(NULL),
      iListInfoFont(NULL),
      iListDetailFont(NULL)
{
    iIcons.clear();
}

ThemeData::~ThemeData()
{
    delete iStatusBarFont;
    delete iTabGradientBrush;
    delete iTabFont;
    delete iListItemPixmap;
    delete iOptionsPixmap;
    delete iMenuPixmap;
    delete iSavePixmap;
    delete iCancelPixmap;
    
    delete iListTitleFont;
    delete iListContentFont;
    delete iListInfoFont;
    delete iListDetailFont;

    iIcons.clear();
}

void ThemeData::Init()
{
    // Status bar
    iStatusBarFont = new QFont("Arial");
    iStatusBarFont->setPixelSize(StatusBarFontPx);
    
    // Tabs
    QLinearGradient ql(0, 0, 0, TabbarHeight);
    ql.setColorAt(0.0, QColor(238,238,238));
    ql.setColorAt(0.5, QColor(216,216,216));
    ql.setColorAt(1.0, QColor(203,203,203));
    iTabGradientBrush = new QBrush(ql);
    iTabFont = new QFont("Arial");
    iTabFont->setPixelSize(10);
    
    const int iconCount = 12;
    QPixmap iconSheet(":/images/icons32-vs.png");
    const int iconWidth = iconSheet.width()/iconCount; 
    
    for (int i=0; i < 12; i++)
    {
        qDebug("WP::Reading %d %d<->%d", i, i*iconWidth, (i+1)*iconWidth);
        iIcons.append(iconSheet.copy(i*iconWidth,0,iconWidth,iconSheet.height()));
    }

    iContextMenuIcons.clear();
    iContextMenuIcons.append(QPixmap(":/images/approve.png"));
    iContextMenuIcons.append(QPixmap(":/images/edit.png"));
    iContextMenuIcons.append(QPixmap(":/images/open.png"));
    iContextMenuIcons.append(QPixmap(":/images/remove.png"));
    iContextMenuIcons.append(QPixmap(":/images/reply.png"));
    iContextMenuIcons.append(QPixmap(":/images/spam.png"));
    iContextMenuIcons.append(QPixmap(":/images/view.png"));
    
    // Lists
    iListItemPixmap = new QPixmap(":/images/listitembg.png");
    iListItemShadowMargin = 4;
    
    iListTitleFont = new QFont("Arial");
    iListTitleFont->setPixelSize(20);
	
    iListContentFont = new QFont("Arial");
    iListContentFont->setPixelSize(14);
	
	iListInfoFont = new QFont("Arial");
	iListInfoFont->setPixelSize(14);
	iListInfoFont->setItalic(true);
	
	iListDetailFont = new QFont("Arial");
	iListDetailFont->setPixelSize(11);
    
    // Menu
    iOptionsPixmap = new QPixmap(":/images/options.png");
    iMenuPixmap = new QPixmap(":/images/menubg.png");
    iSavePixmap = new QPixmap(":/images/save.png");
    iCancelPixmap = new QPixmap(":/images/cancel.png");
}

==> wordpress_0.7.0.tar.gz: wordpress-0.7.0/src/themedatastorage.cpp <==
/*
 * themedatastorage.cpp
 *
 *  Created on: 27.5.2010
 *      Author: jlep
 */

#include <QFont>
#include <QPixmap>
#include <QLinearGradient>

#include "wpcommongeometry.h"
#include "themedatastorage.h"

#ifdef Q_OS_SYMBIAN
//const char* KButtonStyleSheet = "background-color: #ECECEC; font-size: 6pt; margin: 5px 0 3px 0; color: #333333;";
const char* KLabelStyleSheet = "background-color: #ECECEC; font-size: 6pt; margin: 5px 0px 3px 0px; color: #333333;";
#else
//const char* KButtonStyleSheet = "background-color: #ECECEC; font-size: 16pt; margin: 5px 0 3px 0; color: #333333;";
const char* KLabelStyleSheet = "background-color: #ECECEC; font-size: 16pt; margin: 5px 0px 3px 0px; color: #333333;";
#endif

ThemeData::ThemeData() :
      iTabGradientBrush(NULL),
      iTabFont(NULL),
      iListItemPixmap(NULL),
      iListTitleFont(NULL),
      iListContentFont(NULL),
      iListInfoFont(NULL),
      iListDetailFont(NULL)
{
    iIcons.clear();
}

ThemeData::~ThemeData()
{
    delete iTabGradientBrush;
    delete iTabFont;
    delete iListItemPixmap;
    
    delete iListTitleFont;
    delete iListContentFont;
    delete iListInfoFont;
    delete iListDetailFont;

    iIcons.clear();
}

void ThemeData::Init()
{
    // Tabs
    QLinearGradient ql(0, 0, 0, TabbarHeight);
    ql.setColorAt(0.0, QColor(238,238,238));
    ql.setColorAt(0.5, QColor(216,216,216));
    ql.setColorAt(1.0, QColor(203,203,203));
    iTabGradientBrush = new QBrush(ql);
    iTabFont = new QFont("Arial");
    iTabFont->setPixelSize(10);
    
    const int iconCount = 12;
    QPixmap iconSheet(":/images/icons32-vs.png");
    const int iconWidth = iconSheet.width()/iconCount; 
    
    for (int i=0; i < 12; i++)
    {
        qDebug("WP::Reading %d %d<->%d", i, i*iconWidth, (i+1)*iconWidth);
        iIcons.append(iconSheet.copy(i*iconWidth,0,iconWidth,iconSheet.height()));
    }

    iContextMenuIcons.clear();
    iContextMenuIcons.append(QPixmap(":/images/approve.png"));
    iContextMenuIcons.append(QPixmap(":/images/edit.png"));
    iContextMenuIcons.append(QPixmap(":/images/open.png"));
    iContextMenuIcons.append(QPixmap(":/images/remove.png"));
    iContextMenuIcons.append(QPixmap(":/images/reply.png"));
    iContextMenuIcons.append(QPixmap(":/images/spam.png"));
    iContextMenuIcons.append(QPixmap(":/images/view.png"));
    
    // Lists
    iListItemPixmap = new QPixmap(":/images/listitembg.png");
    iListItemShadowMargin = 4;
    
    iListTitleFont = new QFont("Arial");
    iListTitleFont->setPixelSize(20);
	
    iListContentFont = new QFont("Arial");
    iListContentFont->setPixelSize(14);
	
	iListInfoFont = new QFont("Arial");
	iListInfoFont->setPixelSize(14);
	iListInfoFont->setItalic(true);
	
	iListDetailFont = new QFont("Arial");
	iListDetailFont->setPixelSize(11);
}
